@@ -7,6 +7,9 @@ def handle_response(func):
     @wraps(func)
     def inner_function(*args, **kwargs):
         result = func(*args, **kwargs)
+       
+        if isinstance(result, Response):
+            return result
 
         response = result
         code = 200
